@@ -1,10 +1,10 @@
 BOOTSTRAP = (
-    "https://stackpath.bootstrapcdn.com/bootstrap/4.5.2/css/bootstrap.min.css"
+    "https://cdn.jsdelivr.net/npm/bootstrap@5.1.3/dist/css/bootstrap.min.css"
 )
 
-GRID = "https://stackpath.bootstrapcdn.com/bootstrap/4.5.2/css/bootstrap-grid.min.css"  # noqa
+GRID = "https://cdn.jsdelivr.net/npm/bootstrap@5.1.3/dist/css/bootstrap-grid.min.css"  # noqa
 
-_BOOTSWATCH_BASE = "https://stackpath.bootstrapcdn.com/bootswatch/4.5.2/"
+_BOOTSWATCH_BASE = "https://cdn.jsdelivr.net/npm/bootswatch@5.1.3/dist/"
 
 CERULEAN = _BOOTSWATCH_BASE + "cerulean/bootstrap.min.css"
 COSMO = _BOOTSWATCH_BASE + "cosmo/bootstrap.min.css"
@@ -17,7 +17,9 @@ LUMEN = _BOOTSWATCH_BASE + "lumen/bootstrap.min.css"
 LUX = _BOOTSWATCH_BASE + "lux/bootstrap.min.css"
 MATERIA = _BOOTSWATCH_BASE + "materia/bootstrap.min.css"
 MINTY = _BOOTSWATCH_BASE + "minty/bootstrap.min.css"
+MORPH = _BOOTSWATCH_BASE + "morph/bootstrap.min.css"
 PULSE = _BOOTSWATCH_BASE + "pulse/bootstrap.min.css"
+QUARTZ = _BOOTSWATCH_BASE + "quartz/bootstrap.min.css"
 SANDSTONE = _BOOTSWATCH_BASE + "sandstone/bootstrap.min.css"
 SIMPLEX = _BOOTSWATCH_BASE + "simplex/bootstrap.min.css"
 SKETCHY = _BOOTSWATCH_BASE + "sketchy/bootstrap.min.css"
@@ -26,4 +28,6 @@ SOLAR = _BOOTSWATCH_BASE + "solar/bootstrap.min.css"
 SPACELAB = _BOOTSWATCH_BASE + "spacelab/bootstrap.min.css"
 SUPERHERO = _BOOTSWATCH_BASE + "superhero/bootstrap.min.css"
 UNITED = _BOOTSWATCH_BASE + "united/bootstrap.min.css"
+VAPOR = _BOOTSWATCH_BASE + "vapor/bootstrap.min.css"
 YETI = _BOOTSWATCH_BASE + "yeti/bootstrap.min.css"
+ZEPHYR = _BOOTSWATCH_BASE + "zephyr/bootstrap.min.css"
